@@ -2,7 +2,7 @@ use strict;
 
 package HTTP::BrowserDetect;
 {
-  $HTTP::BrowserDetect::VERSION = '1.42';
+  $HTTP::BrowserDetect::VERSION = '1.43';
 }
 
 use vars qw(@ISA @EXPORT @EXPORT_OK @ALL_TESTS);
@@ -139,7 +139,7 @@ push @ALL_TESTS,
     (
     @OS_TESTS,          @WINDOWS_TESTS, @MAC_TESTS,
     @UNIX_TESTS,        @BSD_TESTS,     @GAMING_TESTS,
-    keys %DEVICE_TESTS, @BROWSER_TESTS, @IE_TESTS,
+    sort ( keys %DEVICE_TESTS ), @BROWSER_TESTS, @IE_TESTS,
     @OPERA_TESTS,       @AOL_TESTS,     @NETSCAPE_TESTS,
     @FIREFOX_TESTS,     @ENGINE_TESTS,  @ROBOT_TESTS,
     @MISC_TESTS,
@@ -1137,7 +1137,7 @@ sub device {
 
     my ( $self, $check ) = _self_or_default( @_ );
 
-    foreach my $device ( keys %DEVICE_TESTS ) {
+    foreach my $device ( sort keys %DEVICE_TESTS ) {
         return $device if ( $self->$device );
     }
 
@@ -1209,7 +1209,7 @@ sub browser_properties {
     my ( $self, $check ) = _self_or_default( @_ );
 
     my @browser_properties;
-    foreach my $property ( keys %{ $self->{tests} } ) {
+    foreach my $property ( sort keys %{ $self->{tests} } ) {
         push @browser_properties, lc( $property )
             if ( ${ $self->{tests} }{$property} );
     }
@@ -1234,7 +1234,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
@@ -1717,6 +1717,8 @@ Ronald J. Kimball
 
 Bill Rhodes
 
+Thom Blake
+
 =head1 TO DO
 
 The C<_engine()> method currently only handles Gecko and Trident.  It needs to
